<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://polkurier.pl
 * @since      1.0.0
 *
 * @package    Polkurier
 * @subpackage Polkurier/admin/partials
 */

use Polkurier\ApiClient;
use Polkurier\Http\Request;
use Polkurier\PluginInfoProvider;
use Polkurier\ShipmentTemplate\ShipmentTemplate;
use Polkurier\ShipmentTemplate\ShipmentTemplateManager;
use Polkurier\Types\CheckoutPointButtonPosition;
use Polkurier\Types\PackType;
use Polkurier\Types\ShipmentType;
use Polkurier\Util\Arr;

require_once dirname(__FILE__) . '/../../includes/PolkurierPackage.php';
require_once dirname(__FILE__) . '/../../includes/PolkurierAPI.php';
$active_tab = isset($_GET['tab']) ? $_GET['tab'] : 'authorization';
$packages = get_option('polkurier_packages');
$addresses = get_option('polkurier_addresses');
$accounts = get_option('polkurier_accounts');
$coverAddresses = get_option('polkurier_cover_addresses');
$request = new Request();

if (isset($_GET['action']) && $_GET['action'] === 'check-update') {
    (new PluginInfoProvider())
        ->clearCache()
        ->getUpdateInfo();
    return wp_redirect('plugins.php');
}

if (isset($_GET['action']) && $_GET['action'] == 'delete') {
	if ($active_tab == 'templates') {
        $manager = new ShipmentTemplateManager();
        $template = $manager->getById($request->query->getString('id'));
        if ($template !== null) {
            $manager->remove($template);
            $manager->save();
        }
	}
	if ($active_tab == 'addresses') {
		unset($addresses[(int) $_GET['id']]);
		update_option('polkurier_addresses', $addresses);
	}
	if ($active_tab == 'accounts') {
		unset($accounts[(int) $_GET['id']]);
		update_option('polkurier_accounts', $accounts);
	}
    if ($active_tab == 'cover_addresses') {
        unset($coverAddresses[(int) $_GET['id']]);
        update_option('polkurier_accounts', $coverAddresses);
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if ($active_tab === 'templates') {

        $manager = new ShipmentTemplateManager();
        $template = null;
        if (!empty($request->request->getString('id'))) {
            $template = $manager->getById($request->request->getString('id'));
        }

        if ($template === null) {
            $template = new ShipmentTemplate();
        }

		$template->name = $request->request->getString('name');
		$template->courier = $request->request->getString('courier');
        $template->width = $request->request->getFloat('width');
        $template->height = $request->request->getFloat('height');
        $template->length = $request->request->getFloat('length');
        $template->weight = $request->request->getFloat('weight');
        $template->amount = $request->request->getInt('amount');
        $template->default = $request->request->getBoolean('default');

        $type = explode('::', $request->request->getString('type'));
		$template->shipment_type = $type[0];
		$template->type = $type[1];

        $manager->persist($template);
        if ($template->default) {
            $manager->setDefault($template);
        }
        $manager->save();
    }
    if ($active_tab == 'accounts') {
        // zapisujemy informacje o nowym koncie
        $account = null;
        if (isset($_GET['id'], $accounts[$_GET['id']])) {
            $account = $accounts[$_GET['id']];
        }

        if ($account === null) {
            $account = new PolkurierBankAccount();
        }

		$account->account = $request->request->getString('polkurier_account');
		$account->alias = $request->request->getString('polkurier_account_name');
        if (isset($_GET['id'])) {
            $accounts[$_GET['id']] = $account;
        } else {
            $accounts[] = $account;
        }

        foreach ($accounts as $acc) {
            if (empty($acc->id)) {
                $acc->id = sha1(uniqid('PolkurierBankAccount', true));
            }
        }

        if ($request->request->getBoolean('polkurier_default')) {
            foreach ($accounts as $acc) {
                $acc->default = $acc === $account;
            }
        }

        update_option('polkurier_accounts', $accounts);
    }
    if ($active_tab == 'addresses') {
		if (!isset($_POST['polkurier_id'])) {
			// zapisujemy informacje o nowym adresie
			$address = new PolkurierAddress();
		} else {
			$address = PolkurierAddress::getAddressById($_POST['polkurier_id']);
		}

        $address->address["company"] = $_POST["polkurier_company_name"];
        $address->address["person"] = $_POST["polkurier_name_surname"];
        $address->address["street"] = $_POST["polkurier_street"];
        $address->address["housenumber"] = $_POST["polkurier_number_1"];
        $address->address["flatnumber"] = $_POST["polkurier_number_2"];
        $address->address["postcode"] = $_POST["polkurier_postal_code"];
        $address->address["city"] = $_POST["polkurier_city"];
        $address->address["phone"] = $_POST["polkurier_phone"];
		$address->address["email"] = $_POST["polkurier_email"];
		$address->address["account_id"] = $_POST["polkurier_polkurier_account_id"];

        if ($request->request->getBoolean('polkurier_default_address')) {
            foreach ($addresses as $i => $addr) {
                $addr->default = false;
            }
            $address->default = true;
        }

        foreach ($addresses as $addr) {
            if (empty($address->uuid)) {
                $address->uuid = sha1(uniqid('addr', true));
            }
        }

		if (!isset($_POST['polkurier_id'])) {
			$addresses[] = $address;
		} else {
			$addresses[$_POST['polkurier_id']] = $address;
		}

		update_option('polkurier_addresses', $addresses);
    }

//    SAVE COVER ADDRESS
    if ($active_tab == 'cover_addresses') {
        if (!isset($_POST['polkurier_id'])) {
            // zapisujemy informacje o nowym adresie
            $coverAddress = new PolkurierAddress();
        } else {
            $coverAddress = PolkurierAddress::getCoverAddressById($_POST['polkurier_id']);
        }
        $coverAddress->cover_address = true;
        $coverAddress->address["company"] = $_POST["polkurier_company_name"];
        $coverAddress->address["person"] = $_POST["polkurier_name_surname"];
        $coverAddress->address["street"] = $_POST["polkurier_street"];
        $coverAddress->address["housenumber"] = $_POST["polkurier_number_1"];
        $coverAddress->address["flatnumber"] = $_POST["polkurier_number_2"];
        $coverAddress->address["postcode"] = $_POST["polkurier_postal_code"];
        $coverAddress->address["city"] = $_POST["polkurier_city"];
        $coverAddress->address["phone"] = $_POST["polkurier_phone"];
        $coverAddress->address["email"] = $_POST["polkurier_email"];
        $coverAddress->address["account_id"] = $_POST["polkurier_polkurier_account_id"];

        if ($request->request->getBoolean('polkurier_default_address')) {
            foreach ($coverAddresses as $i => $addr) {
                $addr->default = false;
            }
            $coverAddress->default = true;
        }

        foreach ($coverAddresses as $addr) {
            if (empty($address->uuid)) {
                $coverAddress->uuid = sha1(uniqid('addr', true));
            }
        }

        if (!isset($_POST['polkurier_id'])) {
            $coverAddresses[] = $coverAddress;
        } else {
            $coverAddresses[$_POST['polkurier_id']] = $coverAddress;
        }
        update_option('polkurier_cover_addresses', $coverAddresses);
    }
//    END SAVE COVER ADDRESS
}
?>
<div class="wrap">
<h2><?php echo esc_html(get_admin_page_title()); ?></h2>
<?php settings_errors();?>
<?php if (isset($_GET['action']) && ($_GET['action'] == 'view')): ?>
<h2>Szczegóły paczki:</h2>
<p>
<?php $details = $this->get_package_details();
echo $this->describe_field("orderNumber", $details["orderNumber"]);
echo $this->describe_field("size", $details["size"]);
echo $this->describe_field("status", $details["status"]);
echo "<table><tr><td style=\"vertical-align: top; padding-right: 4em\">";
echo "<h3>Nadawca:</h3>";
foreach ($details["sender"] as $key => $value) {
    echo $this->describe_field($key, $value);
}
echo "</td><td style=\"vertical-align: top\">";
echo "<h3>Odbiorca:</h3>";
foreach ($details["receiver"] as $key => $value) {
    echo $this->describe_field($key, $value);
}
echo "</td></tr></table>";
echo "<a href=\"?page=polkurier\" class=\"button primary-button\">Powrót</a>";
?>
</p>
<?php else: // default table and settings ?>
	<h2 class="nav-tab-wrapper">
	<a href="?page=polkurier&tab=authorization" class="nav-tab <?php echo $active_tab == 'authorization' ? 'nav-tab-active' : '' ?>">Autoryzacja</a>
	    <a href="?page=polkurier&tab=addresses" class="nav-tab <?php echo $active_tab == 'addresses' ? 'nav-tab-active' : '' ?>">Domyślne adresy</a>
	    <a href="?page=polkurier&tab=cover_addresses" class="nav-tab <?php echo $active_tab == 'cover_addresses' ? 'nav-tab-active' : '' ?>">Adresy na etykiecie</a>
	    <a href="?page=polkurier&tab=accounts" class="nav-tab <?php echo $active_tab == 'accounts' ? 'nav-tab-active' : '' ?>">Konta bankowe</a>
		<a href="?page=polkurier&tab=templates" class="nav-tab <?php echo $active_tab == 'templates' ? 'nav-tab-active' : '' ?>">Szablony paczek</a>
	    <a href="?page=polkurier&tab=carrier" class="nav-tab <?php echo $active_tab == 'carrier' ? 'nav-tab-active' : '' ?>">Domyślny przewoźnik</a>
	    <a href="?page=polkurier&tab=couriers_points" class="nav-tab <?php echo $active_tab == 'couriers_points' ? 'nav-tab-active' : '' ?>">Domyślny paczkomat / punkt nadania</a>
        <a href="?page=polkurier&tab=default_services" class="nav-tab <?php echo $active_tab == 'default_services' ? 'nav-tab-active' : '' ?>">Domyślne wartości</a>
        <a href="?page=polkurier&tab=other" class="nav-tab <?php echo $active_tab == 'other' ? 'nav-tab-active' : '' ?>">Inne</a>
	</h2><?php switch ($active_tab):
		case 'authorization': ?>
		    <form action="options.php" method="post">
<?php
    settings_fields($this->plugin_name . '_authorization');
    do_settings_sections($this->plugin_name . '_authorization');
    submit_button();
    ?>
			</form>
	<?php break;case 'addresses': ?>
	<?php if (!(isset($_GET['action']) && $_GET['action'] == 'edit')): ?>
	<h2>Dostępne adresy</h2>
	<?php else: ?>
	<h2>Edycja adresu</h2>
	<?php endif; ?>
	<table class="wp-list-table widefat fixed striped polkurier-admin-table">
	<?php if ($addresses && count($addresses)>0 && (isset($_GET['action'])?($_GET['action'] != 'edit'):true) ) : ?>
	<thead>
		<tr>
			<th>Nazwa firmy</th>
			<th>Imię i nazwisko</th>
			<th>Adres</th>
			<th>Kod pocztowy i miasto</th>
			<th>Numer telefonu</th>
			<th>E-mail</th>
			<th>ID Polkurier</th>
			<th>Domyślny</th>
			<th>Działania</th>
		</tr>
	</thead>
	<?php endif; ?>
	<?php if (!(isset($_GET['action']) && $_GET['action'] == 'edit') && $addresses) foreach ($addresses as $key => $pkg): ?>

	<tr><?php echo $pkg->asTableRow() ?>
	<td><a href="admin.php?page=polkurier&tab=addresses&action=edit&id=<?php echo $key ?>">edytuj</a>
	<a href="admin.php?page=polkurier&tab=addresses&action=delete&id=<?php echo $key ?>"  onclick="return confirm('Czy na pewno usunąć adres?')">usuń</a></td>
	</tr>
	<?php endforeach?></table>
	<form action="admin.php?page=polkurier&tab=addresses" method="post">
	<?php if (isset($_GET['action']) && $_GET['action'] == 'edit'):
		$adres = PolkurierAddress::getAddressById($_GET['id']);
		$adres->renderForm();
		else: ?>
	<table class="form-table">
	<tbody>
	<tr><th scope="row">
	<label for="polkurier_company_name">Nazwa firmy</label></th>
	<td><input required type="text" name="polkurier_company_name" id="polkurier_company_name" value=""> </td>
	</tr>
	<tr><th scope="row"><label for="polkurier_name_surname_cb">Imię&nbsp;i nazwisko</label></th>
	<td><input required type="text" name="polkurier_name_surname" id="polkurier_name_surname" value=""> </td>
	</tr>
	<tr><th scope="row"><label for="polkurier_street_cb">Ulica</label></th>
	<td><input required type="text" name="polkurier_street" id="polkurier_street" value=""> </td>
	</tr>
	<tr><th scope="row"><label for="polkurier_number_1_cb">Numer budynku</label></th>
	<td><input required type="text" name="polkurier_number_1" id="polkurier_number_1" value=""> </td></tr>
	<tr>
	<th scope="row"><label for="polkurier_number_2_cb">Numer lokalu</label></th>
	<td><input type="text" name="polkurier_number_2" id="polkurier_number_2" value=""> </td></tr>
	<tr>
	<th scope="row"><label for="polkurier_postal_code_cb">Kod pocztowy</label></th>
	<td><input required type="text" pattern="[0-9]{2}-[0-9]{3}" title="Kod pocztowy musi być w formie xx-xxx" name="polkurier_postal_code" id="polkurier_postal_code" value=""> </td></tr>
	<tr><th scope="row"><label for="polkurier_city_cb">Miasto</label></th>
	<td><input required type="text" name="polkurier_city" id="polkurier_city" value=""> </td></tr>
	<tr><th scope="row"><label for="polkurier_phone_cb">Numer telefonu</label></th>
	<td><input required type="text" pattern="[0-9]{9}" title="Podaj dziewięciocyfrowy numer telefonu" name="polkurier_phone" id="polkurier_phone" value=""> </td></tr>
	<tr><th scope="row"><label for="polkurier_email_cb">Adres e-mail</label></th>
	<td><input required type="email" pattern="[a-z0-9._%+-]+@[a-z0-9.-]+\.[a-z]{2,4}$" title="Podaj poprawny adres e-mail" name="polkurier_email" id="polkurier_email" value=""> </td></tr>
    <tr>
        <th scope="row">
            <label for="polkurier_default_address">Domyślny</label>
        </th>
        <td>
            <input type="checkbox" name="polkurier_default_address" value="1" id="polkurier_default_address">
        </td>
    </tr>
    <tr><th scope="row"><label for="polkurier_polkurier_account_id_cb">ID konta Polkurier</label></th>
	<td><input type="text" name="polkurier_polkurier_account_id" id="polkurier_polkurier_account_id" value=""> <br/><em>Opcja dostępna dla klientów nadających przesyłki za pośrednictwem przewoźnika Geis oraz posiadających aktywną opcje stałych odbiorów. ID konta należy pozyskać kontaktując się z biurem obsługi klienta serwisu polkurier.pl.</em></td></tr>
	</tbody></table>
	<?php endif;
    submit_button(((isset($_GET['action']) && $_GET['action'] == 'edit'))?"Zapisz zmiany":"Dodaj adres");
    ?>
			</form>



<!--    COVER ADDRESS FORM-->
<?php break;case 'cover_addresses': ?>
    <?php if (!(isset($_GET['action']) && $_GET['action'] == 'edit')): ?>
    <h2>Dostępne adresy</h2>
<?php else: ?>
    <h2>Edycja adresu</h2>
<?php endif; ?>
    <table class="wp-list-table widefat fixed striped polkurier-admin-table">
        <?php if ($coverAddresses && count($coverAddresses)>0 && (isset($_GET['action'])?($_GET['action'] != 'edit'):true) ) : ?>
            <thead>
            <tr>
                <th>Nazwa firmy</th>
                <th>Imię i nazwisko</th>
                <th>Adres</th>
                <th>Kod pocztowy i miasto</th>
                <th>Numer telefonu</th>
                <th>E-mail</th>
                <th>Domyślny</th>
                <th>Działania</th>
            </tr>
            </thead>
        <?php endif; ?>
        <?php if (!(isset($_GET['action']) && $_GET['action'] == 'edit') && $coverAddresses) foreach ($coverAddresses as $key => $pkg): ?>

            <tr><?php echo $pkg->asTableRow(['account_id'])?>
                <td><a href="admin.php?page=polkurier&tab=cover_addresses&action=edit&id=<?php echo $key ?>">edytuj</a>
                    <a href="admin.php?page=polkurier&tab=cover_addresses&action=delete&id=<?php echo $key ?>"  onclick="return confirm('Czy na pewno usunąć adres?')">usuń</a></td>
            </tr>
        <?php endforeach?></table>
    <form action="admin.php?page=polkurier&tab=cover_addresses" method="post">
        <?php if (isset($_GET['action']) && $_GET['action'] == 'edit'):
            $adres = PolkurierAddress::getCoverAddressById($_GET['id']);
            $adres->renderForm();
        else: ?>
            <table class="form-table">
                <tbody>
                <tr>
                    <th scope="row">
                        <label for="polkurier_company_name">Nazwa firmy</label></th>
                    <td><input type="text" name="polkurier_company_name" id="polkurier_company_name" value="">
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="polkurier_name_surname_cb">Imię&nbsp;i nazwisko</label></th>
                    <td><input type="text" name="polkurier_name_surname" id="polkurier_name_surname" value="">
                    </td>
                </tr>
                <tr>
                    <th scope="row"><label for="polkurier_street_cb">Ulica</label></th>
                    <td><input type="text" name="polkurier_street" id="polkurier_street" value=""></td>
                </tr>
                <tr>
                    <th scope="row"><label for="polkurier_number_1_cb">Numer budynku</label></th>
                    <td><input type="text" name="polkurier_number_1" id="polkurier_number_1" value=""></td>
                </tr>
                <tr>
                    <th scope="row"><label for="polkurier_number_2_cb">Numer lokalu</label></th>
                    <td><input type="text" name="polkurier_number_2" id="polkurier_number_2" value=""></td>
                </tr>
                <tr>
                    <th scope="row"><label for="polkurier_postal_code_cb">Kod pocztowy</label></th>
                    <td><input type="text" pattern="[0-9]{2}-[0-9]{3}"
                               title="Kod pocztowy musi być w formie xx-xxx" name="polkurier_postal_code"
                               id="polkurier_postal_code" value=""></td>
                </tr>
                <tr>
                    <th scope="row"><label for="polkurier_city_cb">Miasto</label></th>
                    <td><input type="text" name="polkurier_city" id="polkurier_city" value=""></td>
                </tr>
                <tr>
                    <th scope="row"><label for="polkurier_phone_cb">Numer telefonu</label></th>
                    <td><input type="text" pattern="[0-9]{9}" title="Podaj dziewięciocyfrowy numer telefonu"
                               name="polkurier_phone" id="polkurier_phone" value=""></td>
                </tr>
                <tr>
                    <th scope="row"><label for="polkurier_email_cb">Adres e-mail</label></th>
                    <td><input type="email" pattern="[a-z0-9._%+-]+@[a-z0-9.-]+\.[a-z]{2,4}$"
                               title="Podaj poprawny adres e-mail" name="polkurier_email" id="polkurier_email" value="">
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="polkurier_default">Domyślny</label>
                    </th>
                    <td>
                        <input type="checkbox" name="polkurier_default" id="polkurier_default">
                    </td>
                </tr>
                </tbody>
            </table>
        <?php endif;
        submit_button(((isset($_GET['action']) && $_GET['action'] == 'edit'))?"Zapisz zmiany":"Dodaj adres");
        ?>
    </form>
<!--    END COVER ADDRESS FORM-->

	<?php break;case 'accounts': ?>
	<h2>Dostępne konta bankowe</h2>
	<table class="wp-list-table widefat striped polkurier-admin-table">
	<thead>
        <tr>
            <th>Nazwa</th>
            <th>Numer rachunku</th>
            <th>Domyślne</th>
            <th>Działania</th>
	    </tr>
	</thead>
	<?php if ($accounts) foreach ($accounts as $key => $pkg): ?>
	<tr>
        <?php echo $pkg->asTableRow() ?>
	    <td>
            <a href="admin.php?page=polkurier&tab=accounts&action=edit&id=<?php echo $key ?>">Edytuj</a>
            &nbsp;
            <a href="admin.php?page=polkurier&tab=accounts&action=delete&id=<?php echo $key ?>" onclick="return confirm('Czy na pewno usunąć numer konta?')">Usuń</a>
        </td>
	</tr>
	<?php endforeach?>
	</table>
    <?php
        $bankAccount = new PolkurierBankAccount();
        if (isset($_GET['action'], $_GET['id']) && $_GET['action'] === 'edit' && isset($accounts[$_GET['id']])) {
            $bankAccount = $accounts[$_GET['id']];
        }
    ?>
	<form action="admin.php?page=polkurier&tab=accounts&<?php echo isset($_GET['id']) ? ('id=' . $_GET['id']) : '' ?>" method="post">
	    <table class="form-table">
            <tbody>
	            <tr>
                    <th scope="row">
                        <label for="polkurier_account_number_name">Nazwa konta bankowego</label>
                    </th>
                    <td>
                        <input required name="polkurier_account_name" id="polkurier_account_name" value="<?php echo $bankAccount->alias ?>">
                    </td>
                </tr>
	            <tr>
                    <th scope="row">
                        <label for="polkurier_account_number_cb">Numer konta bankowego</label>
                    </th>
	                <td>
                        <input required pattern="[0-9]{26}" title="Należy podać 26 cyfr" name="polkurier_account" id="polkurier_account" value="<?php echo $bankAccount->account ?>">
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="polkurier_default">Domyślne</label>
                    </th>
                    <td>
                        <input type="checkbox" name="polkurier_default" id="polkurier_default" <?php echo $bankAccount->default ? 'checked' : '' ?>>
                    </td>
                </tr>
            </tbody>
        </table>
			<?php
                submit_button($bankAccount->id ? "Zapisz" : "Dodaj konto bankowe", "primary", "submit", true, ['onclick' => 'return fn_polkurier_validate(jQuery(\'#polkurier_account\').val())']);
            ?>
	</form>
	<?php break;case 'templates': ?>

<?php if (!(isset($_GET['action']) && $_GET['action'] === 'edit')): ?>
    <?php
        $courierById = Arr::indexBy(ApiClient::getInstance()->getAvailableCarriers(), 'servicecode');
    ?>

	<h2>Dostępne szablony paczek</h2>
	<table class="wp-list-table widefat fixed striped polkurier-admin-table">
	<thead>
		<tr>
            <th>Nazwa</th>
		    <th>Rodzaj</th>
            <th>Wymiary</th>
            <th>Waga</th>
            <th>Ilość</th>
            <th>Domyślny</th>
            <th>Przewoźnik</th>
            <th>Działania</th>
		</tr>
	</thead>
	<?php foreach ((new ShipmentTemplateManager())->getAll() as $template): ?>
	    <tr>
            <td><?php echo $template->name ?></td>
            <td><?php echo PackType::getDisplayName($template->type, $template->shipment_type) ?></td>
            <td><?php echo $template->height . '×' . $template->width . '×' . $template->length . 'cm' ?></td>
            <td><?php echo $template->weight . 'kg' ?></td>
            <td><?php echo $template->amount ?></td>
            <td><?php echo $template->default ? 'TAK' : '' ?></td>
            <td><?php
                if (!empty($template->courier)) {
                    if (isset($courierById[$template->courier]['name'])) {
                        echo $courierById[$template->courier]['name'];
                    } else {
                        echo $template->courier;
                    }
                } else {
                    echo '–';
                }
            ?></td>
            <td>
                <div style="display: flex; gap: 1rem;">
                    <a href="admin.php?page=polkurier&tab=templates&action=edit&id=<?php echo $template->id ?>">Edytuj</a>
                    <a href="admin.php?page=polkurier&tab=templates&action=delete&id=<?php echo $template->id ?>" onclick="return confirm('Czy na pewno usunąć szablon?')">Usuń</a>
                </div>
	        </td>
        </tr>
	<?php endforeach ?>
	</table>
<?php endif; ?>

<?php
    $template = $request->query->getString('id')
        ? (new ShipmentTemplateManager())->getById($request->query->getString('id'))
        : null;

    if ($template === null) {
        $template = new ShipmentTemplate();
    }
?>
<form action="admin.php?page=polkurier&tab=templates" method="post">
    <?php if (isset($_GET['action']) && $_GET['action'] === 'edit'): ?>
        <h2>Edycja szablonu paczki</h2>
    <?php else: ?>
        <h2>Dodaj nowy szablon paczki</h2>
    <?php endif; ?>

    <input type="hidden" name="id" value="<?php echo $template->id ?>">
    <table class="form-table">
        <tbody>
            <tr>
                <th scope="row">
                    <label for="polkurier_name">Nazwa na listę</label>
                </th>
                <td>
                    <input required type="text" name="name" id="polkurier_name" value="<?php echo $template->name ?>">
                </td>
            </tr>
            <tr>
                <th scope="row">
                    <label for="polkurier_height">Wysokość (cm)</label>
                </th>
                <td>
                    <input required type="number" name="height" id="polkurier_height" value="<?php echo $template->height > 0 ? $template->height : '' ?>">
                </td>
            </tr>
            <tr>
                <th scope="row">
                    <label for="polkurier_width">Szerokość (cm)</label>
                </th>
                <td>
                    <input required type="number" name="width" id="polkurier_width" min="1" value="<?php echo $template->width > 0 ? $template->width : '' ?>">
                </td>
            </tr>
            <tr>
                <th scope="row">
                    <label for="polkurier_depth">Długość (cm)</label>
                </th>
                <td>
                    <input required type="number" name="length" id="polkurier_depth" min="1" value="<?php echo $template->length > 0 ? $template->length : '' ?>">
                </td>
            </tr>
            <tr>
                <th scope="row">
                    <label for="polkurier_weight">Waga (kg)</label>
                </th>
                <td>
                    <input required type="number" name="weight" id="polkurier_weight" min="1" value="<?php echo $template->weight > 0 ? $template->weight : '' ?>">
                </td>
            </tr>
            <tr>
                <th scope="row">
                    <label for="polkurier_count">Ilość</label>
                </th>
                <td>
                    <input required type="number" name="amount" id="polkurier_count" min="1" value="<?php echo $template->amount > 0 ? $template->amount : '' ?>">
                </td>
            </tr>
            <tr>
            <th scope="row">
                <label>Typ przesyłki</label>
            </th>
            <td>
                <select name="type">
                    <?php foreach (ShipmentType::PACK_TYPES as $shipmentType => $packTypes): ?>
                        <optgroup label="<?php echo ShipmentType::getDisplayName($shipmentType) ?>">
                            <?php foreach ($packTypes as $packType): ?>
                                <option
                                    value="<?php echo $shipmentType . '::' . $packType ?>"
                                    <?php echo $template->shipment_type === $shipmentType && $template->type === $packType ? 'selected' : '' ?>
                                >
                                    <?php echo PackType::getDisplayName($packType, $shipmentType) ?>
                                </option>
                            <?php endforeach; ?>
                        </optgroup>
                    <?php endforeach; ?>
                </select>
            </td>
        </tr>
        <tr>
            <th scope="row">
                <label>Domyślny przewoźnik</label>
            </th>
            <td>
                <select name="courier">
                    <option value="">Brak domyślnego</option>
                    <?php foreach (ApiClient::getInstance()->getAvailableCarriers() as $courier): ?>
                        <option
                            value="<?php echo $courier['servicecode'] ?>"
                            <?php echo $template->courier === $courier['servicecode'] ? 'selected' : '' ?>
                        >
                            <?php echo $courier['name'] ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </td>
        </tr>
            <tr>
                <th scope="row">
                    <label for="polkurier_default">Domyślny szablon</label>
                </th>
                <td>
                    <input type="checkbox" name="default" id="polkurier_default" <?php echo $template->default ? 'checked' : '' ?>>
                </td>
            </tr>
        </tbody>
    </table>
	<?php submit_button();?>
</form>
<?php break;case 'carrier': ?>
<form action="options.php" method="post">
		<?php
settings_fields($this->plugin_name . '_default_carrier');
do_settings_sections($this->plugin_name . '_default_carrier');
submit_button();
?>
		</form>
<?php break; ?>

<?php case 'couriers_points': ?>
    <?php
        $couriers = [[
            'name' => 'INPOST_PACZKOMAT',
            'title' => 'Paczkomaty InPost',
        ], [
            'name' => 'POCZTEX_PUNKT',
            'title' => 'Pocztex Punkt',
        ], [
            'name' => 'DPD',
            'title' => 'Punkt DPD'
        ], [
            'name' => 'DHL_POINT',
            'title' => 'Punkt DHL'
        ], [
            'name' => 'UPS_AP_POINT_POINT',
            'title' => 'UPS'
        ]];
        $mapToken = (new \Polkurier\MapsTokenManager())->getToken();
    ?>
        <div class="pk-flex-row">
            <?php foreach ($couriers as $courier): ?>
                <div class="pk-flex-col-6">
                    <div class="pk-card pk-mt-5 pk-mx-2 pk-shadow" style="background: white;">
                        <div class="pk-card-header">
                            <?php echo $courier['title'] ?>
                        </div>
                        <div class="pk-card-body">
                            <div id="default-courier-point-label-<?php echo $courier['name'] ?>" class="pk-p-2 pk-m-2 pk-border-1">
                                <?php if (get_option('polkurier_default_point_id_' . $courier['name'])): ?>
                                    [<?php echo get_option('polkurier_default_point_id_' . $courier['name']) ?>]
                                    <?php echo get_option('polkurier_default_point_label_' . $courier['name']) ?>
                                <?php else: ?>
                                    BRAK
                                <?php endif ?>
                            </div>
                            <div style="text-align: center">
                                <button type="button" class="button button-primary" id="default-courier-point-map-<?php echo $courier['name'] ?>">Wybierz z mapy</button>
                                <button type="button" class="button button-primary" id="delete-default-courier-point-map-<?php echo $courier['name'] ?>">Wyczyść</button>
                            </div>
                        </div>
                    </div>
                </div>
            <?php endforeach ?>
        </div>
        <script>
            var initMapAction = function (options) {
                console.log(options);

                options.$deleteButton.on('click', function () {
                    if (!confirm('Na pewno usunąć wybrany punkt?')) {
                        return;
                    }
                    POLKURIER.showLoadingSpinner(options.$deleteButton);
                    jQuery
                        .post(POLKURIER.ajaxUrl, {
                            _ajax_nonce: POLKURIER.ajaxNonce,
                            action: '/polkurier/pickup_points/set_default',
                            courier: options.courier,
                        })
                        .success(function () {
                            options.$label.text('BRAK');
                        })
                        .always(function () {
                            POLKURIER.hideLoadingSpinner(options.$deleteButton);
                        });
                });

                options.$button.on('click', function () {
                    var map = new POLKURIER.PointsMap({
                        token: '<?php echo $mapToken->getToken() ?>',
                        providers: options.providers,
                        functions: ['send'],
                    });
                    map.onConfirm(function (point) {
                        var label = point.street + ', ' + point.zip + ' ' + point.city;
                        options.$label.text('[' + point.id + '] ' + label);
                        POLKURIER.showLoadingSpinner(options.$button);
                        jQuery
                            .post(POLKURIER.ajaxUrl, {
                                _ajax_nonce: POLKURIER.ajaxNonce,
                                action: '/polkurier/pickup_points/set_default',
                                courier: options.courier,
                                pointId: point.id,
                                pointLabel: label
                            })
                            .always(function () {
                                POLKURIER.hideLoadingSpinner(options.$button);
                            });
                        map.closeMapDialog();
                    });
                    map.showMapDialog();
                });
            };

            var couriers = {
                INPOST_PACZKOMAT: {
                    providers: ['INPOST_PACZKOMAT',]
                },
                POCZTEX_PUNKT: {
                    providers: ['POCZTEX_PUNKT'],
                },
                DPD: {
                    providers: ['DPD_POINT'],
                },
                DHL_POINT: {
                    providers: ['DHL_POINT'],
                },
                UPS_AP_POINT_POINT: {
                    providers: ['UPS_AP_POINT_POINT'],
                },
            };

            for (var name in couriers) {
                initMapAction(Object.assign({
                    $button: jQuery('#default-courier-point-map-' + name),
                    $deleteButton: jQuery('#delete-default-courier-point-map-' + name),
                    $label: jQuery('#default-courier-point-label-' + name),
                    courier: name,
                }, couriers[name] || {}));
            }

        </script>
<?php break; ?>
<?php case 'default_services': ?>
    <?php
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            update_option('polkurier_default_courierservice_INSURANCE', Arr::get($_POST, 'INSURANCE') === '1' ? '1' : '');
            update_option('polkurier_default_courierservice_SMS_NOTIFICATION_RECIPIENT', Arr::get($_POST, 'SMS_NOTIFICATION_RECIPIENT') === '1' ? '1' : '');
            update_option('polkurier_default_courierservice_SMS_NOTIFICATION_RECIPIENT_WITH_NAME', Arr::get($_POST, 'SMS_NOTIFICATION_RECIPIENT_WITH_NAME') === '1' ? '1' : '');
            update_option('polkurier_default_courierservice_COVER_ADDRESS_SENDER', Arr::get($_POST, 'COVER_ADDRESS_SENDER') === '1' ? '1' : '');
            update_option('polkurier_DEFAULT_COD_TYPE', Arr::get($_POST, 'DEFAULT_COD_TYPE', ''));
            update_option('polkurier_DEFAULT_COD_RETURN_TYPE', Arr::get($_POST, 'DEFAULT_COD_RETURN_TYPE', ''));
        }
    ?>
    <form method="POST" class="pk-card pk-mt-5 pk-mx-auto pk-w-75 pk-shadow" style="background: white;">
        <div class="pk-card-header">
            Usługi domyślnie włączone
        </div>
        <div class="pk-card-body">
            <p>
                Usługi te będą automatycznie włączone w formularzu wysyłki
            </p>
            <div class="pk-my-4">
                <label>
                    <input type="checkbox" name="INSURANCE" <?php echo get_option('polkurier_default_courierservice_INSURANCE') === '1' ? 'checked' : '' ?> value="1" />
                    <strong>Ubezpieczenie</strong>
                </label>
                <div class="pk-ml-5">
                    <small>Przesyłka będzie ubezpieczona na wartość zamówienia</small>
                </div>
            </div>
            <div class="pk-my-4">
                <label>
                    <input type="checkbox" name="SMS_NOTIFICATION_RECIPIENT" <?php echo get_option('polkurier_default_courierservice_SMS_NOTIFICATION_RECIPIENT') === '1' ? 'checked' : '' ?> value="1" />
                    <strong>Powiadomienie SMS dla odbiorcy</strong>
                </label>
                <div class="pk-ml-5">
                    <small>Powiadomienie zostanie wysłane po odebraniu przesyłki od nadawcy</small>
                </div>
            </div>
            <div class="pk-my-4">
                <label>
                    <input type="checkbox" name="SMS_NOTIFICATION_RECIPIENT_WITH_NAME" <?php echo get_option('polkurier_default_courierservice_SMS_NOTIFICATION_RECIPIENT_WITH_NAME') === '1' ? 'checked' : '' ?> value="1" />
                    <strong>Powiadomienie SMS dla odbiorcy z własną nazwą nadawcy</strong>
                </label>
                <div class="pk-ml-5">
                    <small>
                        Powiadomienie zostanie wysłane po odebraniu przesyłki od nadawcy<br>
                        Jako nadawca wiadomości będzie widnieć Twoja nazwa.<br>
                        Wymagane jest ustawienie domyślnej nazwy nadawcy w panelu klienta na portalu
                        <a href="https://polkurier.pl">Polkurier.pl</a> w zakładce "Ustawienia" &rarr; "Powiadomienia"
                    </small>
                </div>
            </div>
            <div class="pk-my-4">
                <label>
                    <input type="checkbox" name="COVER_ADDRESS_SENDER" <?php echo get_option('polkurier_default_courierservice_COVER_ADDRESS_SENDER') === '1' ? 'checked' : '' ?> value="1" />
                    <strong>Inny adres nadawcy na etykiecie</strong>
                </label>
                <div class="pk-ml-5">
                    <small>
                        Usługa umożliwia zakrycie Twojego rzeczywistego adresu nadawczego na liście przewozowym.<br>
                        Zostanie wybrany domyślny adres z listy adresów. Adresami można zarządzać w zakładce
                        <a href="?page=polkurier&amp;tab=cover_addresses">
                            "WooCommerce" → "Ustawienia Polkurier" → "Adresy na etykiecie"
                        </a>
                    </small>
                </div>
            </div>

            <hr>

            <div class="pk-my-4">
                <label>
                    <div>
                        <strong>Domyślny rodzaj pobrania</strong>
                    </div>
                    <?php
                        $DEFAULT_COD_TYPE = get_option('polkurier_DEFAULT_COD_TYPE');
                        if (empty($DEFAULT_COD_TYPE)) {
                            $DEFAULT_COD_TYPE = 'S';
                        }
                    ?>
                    <select name="DEFAULT_COD_TYPE">
                        <option value="S" <?php echo $DEFAULT_COD_TYPE === 'S' ? 'selected' : '' ?> >STANDARD – Zwrot pobrania od 5 do 7 dni roboczych w zależności od przewoźnika</option>
                        <option value="1D" <?php echo $DEFAULT_COD_TYPE === '1D' ? 'selected' : '' ?> >Zwrot pobrania w 1 dzień roboczy od daty dostarczenia przesyłki</option>
                        <option value="4D" <?php echo $DEFAULT_COD_TYPE === '4D' ? 'selected' : '' ?> >Zwrot pobrania w 4 dni robocze od daty dostarczenia przesyłki</option>
                        <option value="16D" <?php echo $DEFAULT_COD_TYPE === '16D' ? 'selected' : '' ?> >Zwrot w 16 dni roboczych od daty dostarczenia przesyłki</option>
                    </select>
                </label>
            </div>
            <div class="pk-my-4">
                <label>
                    <div>
                        <strong>Domyślny rodzaj zwrotu pobrania</strong>
                    </div>
                    <?php
                        $DEFAULT_COD_RETURN_TYPE = get_option('polkurier_DEFAULT_COD_RETURN_TYPE');
                        if (empty($DEFAULT_COD_RETURN_TYPE)) {
                            $DEFAULT_COD_RETURN_TYPE = 'BA';
                        }
                    ?>
                    <select name="DEFAULT_COD_RETURN_TYPE">
                        <option value="BA" <?php echo $DEFAULT_COD_RETURN_TYPE === 'BA' ? 'selected' : '' ?> >Przelew na konto bankowe</option>
                        <option value="PO" <?php echo $DEFAULT_COD_RETURN_TYPE === 'PO' ? 'selected' : '' ?> >Przekaz pocztowy na adres nadawcy</option>
                        <option value="MB" <?php echo $DEFAULT_COD_RETURN_TYPE === 'MB'  ? 'selected' : '' ?> >Do skarbonki </option>
                    </select>
                </label>
            </div>

            <div style="text-align: center" class="pk-mt-4">
                <button type="submit" class="button button-primary" id="delete-default-courier-point-map-INPOST_PACZKOMAT">Zapisz</button>
            </div>
        </div>
    </form>
    <script>
        (function () {
            var $smsNotificationRecipient = jQuery('[name="SMS_NOTIFICATION_RECIPIENT"]');
            var $smsNotificationRecipientWithName = jQuery('[name="SMS_NOTIFICATION_RECIPIENT_WITH_NAME"]');
            $smsNotificationRecipient.on('change', function () {
                $smsNotificationRecipientWithName.prop('checked', false);
            });
            $smsNotificationRecipientWithName.on('change', function () {
                $smsNotificationRecipient.prop('checked', false);
            });
        }) ();
    </script>
<?php break; ?>
<?php case 'other': ?>
<?php
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        update_option('polkurier_layout_checkout_full_row', Arr::get($_POST, 'polkurier_layout_checkout_full_row') === '1' ? '1' : '');
        update_option('polkurier_layout_checkout_point_button_position', (string)Arr::get($_POST, 'polkurier_layout_checkout_point_button_position'));
    }
?>
    <form method="POST" class="pk-card pk-mt-5 pk-mx-auto pk-w-75 pk-shadow" style="background: white;">
        <div class="pk-card-header">
            Wygląd
        </div>
        <div class="pk-card-body">
            <div class="pk-my-4">
                <label>
                    <input type="checkbox" name="polkurier_layout_checkout_full_row" <?php echo get_option('polkurier_layout_checkout_full_row') === '1' ? 'checked' : '' ?> value="1" />
                    <strong>Przycisk "Wybierz paczkomat" / "Wybierz punkt" w jednej komórce</strong>
                </label>
                <div class="pk-ml-5">
                    <small>
                        Szablon HTML WooCommerce wykorzystuje tabelki w ostatnim kroku zamówienia,
                        gdzie w lewej komórce zawarty jest tytuł wiersza, a w prawej treść lub opcje do wyboru.
                        Po zaznaczeniu tej opcji komórki zostaną scalone w jedną na całą szerokość wiersza.
                    </small>
                </div>
            </div>

            <div class="pk-my-4">
                <label>
                    <div>
                        <strong>Pozycja przycisku "Wybierz paczkomat" / "Wybierz punkt"</strong>
                    </div>
                    <?php
                        $LAYOUT_CHECKOUT_POINT_BUTTON_POSITION = (string)get_option('polkurier_layout_checkout_point_button_position');
                    ?>
                    <select name="polkurier_layout_checkout_point_button_position">
                        <?php foreach (CheckoutPointButtonPosition::NAMES as $id => $name): ?>
                            <option value="<?php echo $id ?>" <?php echo $LAYOUT_CHECKOUT_POINT_BUTTON_POSITION === $id ? 'selected' : '' ?>>
                                <?php echo $name ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </label>
            </div>

            <hr>
            <div style="text-align: center" class="pk-mt-4">
                <button type="submit" class="button button-primary" id="delete-default-courier-point-map-INPOST_PACZKOMAT">Zapisz</button>
            </div>
        </div>
    </form>
<?php break; ?>
<?php
    endswitch;
    endif;
?>
</div>
<script type="text/javascript">
function fn_polkurier_validate(input)
{
	input = "PL" + input;
    var iban = String(input).toUpperCase().replace(/[^A-Z0-9]/g, ''),
            code = iban.match(/^([A-Z]{2})(\d{2})([A-Z\d]+)$/),
            digits;
    digits = (code[3] + code[1] + code[2]).replace(/[A-Z]/g, function (letter) {
        return letter.charCodeAt(0) - 55;
    });
    if (mod97(digits) === 1) {
		return true;
	}
	else {
		alert("Niepoprawny numer rachunku bankowego");
		return false;
	}
}

function mod97(string) {
    var checksum = string.slice(0, 2), fragment;
    for (var offset = 2; offset < string.length; offset += 7) {
        fragment = String(checksum) + string.substring(offset, offset + 7);
        checksum = parseInt(fragment, 10) % 97;
    }
    return checksum;
}
</script>
