<?php

namespace Polkurier;

/**
 * @template T
 */
abstract class AbstractSimpleObjectManager
{

    /**
     * @var T[]
     */
    private static $items;

    /**
     * @return string
     */
    public static function generateId()
    {
        return sha1(uniqid(__CLASS__, true));
    }

    /**
     * @return string
     */
    abstract protected function getWPOptionName();

    /**
     * @param array $data
     * @return T
     */
    abstract public function fromArray($data);

    /**
     * @param string $id
     * @return T|null
     */
    public function getById($id)
    {
        foreach ($this->getAll() as $template) {
            if ($template->id === $id) {
                return $template;
            }
        }
        return null;
    }

    /**
     * @return T[]
     */
    public function getAll()
    {
        if (static::$items === null) {
            static::$items = [];
            $data = (array)json_decode(get_option($this->getWPOptionName()), true);
            foreach ($data as $row) {
                static::$items[] = $this->fromArray($row);
            }
        }
        return static::$items;
    }

    /**
     * @param T $template
     * @return self
     */
    public function persist($template)
    {
        $previousTemplate = $this->getById($template->id);
        if ($previousTemplate === null) {
            self::$items[] = $template;
        }
        return $this;
    }

    /**
     * @param T $template
     * @return $this
     */
    public function remove($template)
    {
        $this->getAll();
        self::$items = array_filter(self::$items, static function ($t) use ($template) {
            return $t !== $template;
        });
        return $this;
    }

    /**
     * @return self
     */
    public function save()
    {
        foreach ($this->getAll() as $template) {
            if ($template->id === null) {
                $template->id = self::generateId();
            }
        }
        update_option($this->getWPOptionName(), json_encode($this->getAll()));
        return $this;
    }

}
