<?php

namespace Polkurier\Http;

use Exception;
use Polkurier\Exception\HttpException;

class AjaxRouter
{

    public function registerHandler($path, $handlerOrClassName, $methodName = 'indexAction')
    {
        add_action("wp_ajax_$path", function () use ($handlerOrClassName, $methodName) {
            if (is_callable($handlerOrClassName)) {
                $this->handlerRequest($handlerOrClassName);
            }

            if (is_string($handlerOrClassName) && class_exists($handlerOrClassName)) {
                $this->handlerRequest(function (Request $request) use ($handlerOrClassName, $methodName) {
                    return (new $handlerOrClassName())->$methodName($request);
                });
            }

            if (is_object($handlerOrClassName) && method_exists($handlerOrClassName, $methodName)) {
                $this->handlerRequest(function (Request $request) use ($handlerOrClassName, $methodName) {
                    return $handlerOrClassName->$methodName($request);
                });
            }

            return null;
        });
        return $this;
    }

    /**
     * @param callable $action
     */
    public function handlerRequest(callable $action)
    {
        check_ajax_referer( 'polkurier-nonce' );
        try {
            $response = $action(new Request());
            if (!$response instanceof Response) {
                throw new HttpException('Controller must return instance of Response class', 500);
            }
        } catch (HttpException $e) {
            $response = new JsonResponse(['error' => $e->getMessage()], $e->getCode());
        } catch (Exception $e) {
            $response = new JsonResponse(['error' => $e->getMessage()], 500);
        }
        $response->send();
        exit;
    }

}
