<?php

namespace Polkurier;

use DateTime;
use Polkurier;

class PluginInfo
{

    /**
     * @var string
     */
    public $version = '';

    /**
     * @var string
     */
    public $tested = '';

    /**
     * @var DateTime|null
     */
    public $date = null;

    /**
     * @var string
     */
    public $package_url = '';

    /**
     * @var string
     */
    public $readme_url = '';

    /**
     * @var string
     */
    public $changelog = '';

    /**
     * @var array
     */
    public $require = [];

    public function getDependencyVersion($name)
    {
        return is_array($this->require) && isset($this->require[$name]) ? $this->require[$name] : '';
    }

    public function isUpdateAvailable()
    {
        return version_compare(Polkurier::instance()->get_version(), $this->version, '<');
    }

    public function isUpdateCompatible()
    {
        global $wp_version;

        if (!empty($this->require)) {
            foreach ($this->require as $dependency => $version) {
                if ($version === '*') {
                    continue;
                }

                if (strpos($version, ' ') !== false) {
                    $version = explode(' ', trim($version))[0];
                }

                $installedVersion = '';
                switch ($dependency) {
                    case 'php':
                        $installedVersion = PHP_VERSION;
                        break;

                    case 'wordpress':
                        $installedVersion = $wp_version;
                        break;

                    case 'woocommerce':
                        if (function_exists('WC')) {
                            $installedVersion = WC()->version;
                        }
                        break;
                }

                if (!version_compare($installedVersion, trim($version), '>=')) {
                    return false;
                }
            }
        }
        return true;
    }

}
