<?php

namespace Polkurier;

use DateTime;
use Polkurier;
use Polkurier\Util\Dates;
use Polkurier\Util\ParameterBag;

class PluginInfoProvider
{

    /**
     * @var ParameterBag
     */
    private static $manifest;

    const TRANSIENT_KEY = 'PolkurierUpdateManifest';
    const MANIFEST_URL = Polkurier::POLKURIER_URL . '/updatemodule/woocommerce/manifest.json';
    const UPDATE_INTERVAL = 10800; // 3H

    /**
     * @return $this
     */
    public function clearCache()
    {
        delete_transient(self::TRANSIENT_KEY);
        return $this;
    }

    /**
     * @return ParameterBag|null
     */
    private function getVersionManifest()
    {
        if (self::$manifest === null) {
            $remote = get_transient(self::TRANSIENT_KEY);
            if ($remote === false) {
                $remote = wp_remote_get(self::MANIFEST_URL, [
                    'timeout' => 10,
                    'headers' => [
                        'Accept' => 'application/json'
                    ]
                ]);
                if (is_wp_error($remote) || wp_remote_retrieve_response_code($remote) !== 200 || empty(wp_remote_retrieve_body($remote))) {
                    return null;
                }
                set_transient(self::TRANSIENT_KEY, $remote, self::UPDATE_INTERVAL);
            }
            self::$manifest = new ParameterBag((array)json_decode(wp_remote_retrieve_body($remote), true));
        }
        return self::$manifest;
    }

    /**
     * @return PluginInfo|null
     */
    public function getUpdateInfo()
    {
        $manifest = $this->getVersionManifest();
        if ($manifest === null) {
            return null;
        }
        $pluginInfo = new PluginInfo();
        $pluginInfo->version = (string)$manifest->get('version');
        $pluginInfo->tested = (string)$manifest->get('tested');
        $pluginInfo->date = Dates::dateTimeOrNull((string)$manifest->get('date'));
        if ($pluginInfo->date === null) {
            $pluginInfo->date = new DateTime('1970-01-01 00:00:00');
        }
        $pluginInfo->package_url = (string)$manifest->get('package_url');
        $pluginInfo->readme_url = (string)$manifest->get('readme_url');
        $pluginInfo->changelog = (string)$manifest->get('changelog');
        $pluginInfo->require = (array)$manifest->get('require', []);
        return $pluginInfo;
    }

}
