<?php

namespace Polkurier\Upgrade;

use Polkurier;
use Polkurier\PluginInfoProvider;
use stdClass;

class PluginUpgradeManager
{

    /**
     * @var Polkurier
     */
    private $polkurier;

    public function __construct(Polkurier $polkurier)
    {
        $this->polkurier = $polkurier;
    }

    public function initialize()
    {
        add_filter('plugins_api', function ($result, $action, $args) {
            if ($action !== 'plugin_information' || $this->polkurier->getPluginSlug() !== $args->slug) {
                return $result;
            }

            $pluginInfo = (new PluginInfoProvider())->getUpdateInfo();
            if ($pluginInfo === null || $pluginInfo->version === '') {
                return $result;
            }

            $res = new stdClass();
            $res->name = 'Polkurier';
            $res->slug = $this->polkurier->getPluginSlug();
            $res->author = 'Polkurier';
            $res->version = $pluginInfo->version;
            $res->tested = $pluginInfo->tested;
            $res->requires = $pluginInfo->getDependencyVersion('wordpress');
            $res->requires_php = $pluginInfo->getDependencyVersion('php');
            $res->download_link = $pluginInfo->package_url;
            $res->trunk = $pluginInfo->package_url;
            $res->last_updated = $pluginInfo->date->format(DATE_ATOM);
            $res->sections = [
                'changelog' => nl2br($pluginInfo->changelog),
            ];

            return $res;
        }, 20, 3);

        add_filter('site_transient_update_plugins', function ($transient) {
            if (empty($transient->checked)) {
                return $transient;
            }

            $pluginInfo = (new PluginInfoProvider())->getUpdateInfo();
            if ($pluginInfo === null || $pluginInfo->version === '') {
                return $transient;
            }

            if ($pluginInfo->isUpdateAvailable() && $pluginInfo->isUpdateCompatible()) {
                $res = new stdClass();
                $res->slug = $this->polkurier->getPluginSlug();
                $res->plugin = $this->polkurier->getPluginSlug();
                $res->new_version = $pluginInfo->version;
                $res->tested = $pluginInfo->tested;
                $res->package = $pluginInfo->package_url;
                $transient->response[$res->plugin] = $res;
            }

            return $transient;
        });

        // After update
        add_action('upgrader_process_complete', function ($upgrader, $options) {
            if (
                $options['action'] === 'update' &&
                $options['type'] === 'plugin' &&
                isset($options['plugins']) &&
                in_array($this->polkurier->getPluginSlug(), $options['plugins'], true)
            ) {
                (new PluginInfoProvider())->clearCache();
                (new DatabaseUpgrade())->doUpgrade();
            }
        }, 10, 2);
    }

}
