<?php

namespace Polkurier\Util;

final class Arr
{

    /**
     * @param mixed $arr
     * @param string $key
     * @param mixed $default
     * @return mixed|null
     */
    public static function get($arr, $key, $default = null)
    {
        if (is_array($arr) && array_key_exists($key, $arr)) {
            return $arr[$key];
        }
        return $default;
    }


    /**
     * @param array $arr
     * @param string $path
     * @return mixed
     */
    public static function getByPath(&$arr, $path)
    {
        if (empty($path) || empty($arr)) {
            return null;
        }
        $pathParts = explode('.', $path);
        $value = $arr;
        while ($pathItem = array_shift($pathParts)) {
            if (is_array($value)) {
                $value = isset($value[$pathItem]) ? $value[$pathItem] : null;
            } else {
                break;
            }
        }
        return $value;
    }

    private static function getEntityValue($entity, $getter)
    {
        if (is_callable($getter)) {
            return $getter($entity);
        }

        if (is_scalar($entity)) {
            return $entity;
        }

        if (is_array($entity)) {
            return self::get($entity, $getter);
        }

        if (is_object($entity)) {
            if (method_exists($entity, $getter)) {
                return $entity->{$getter}();
            }
            $getterMethod = 'get' . ucfirst($getter);
            if (method_exists($entity, $getterMethod)) {
                return $entity->{$getterMethod}();
            }
            return $entity->{$getter};
        }
        return null;
    }

    public static function groupBy($arr, $groupBy)
    {
        $data = [];
        if (is_array($arr)) {
            foreach ($arr as $item) {
                $key = self::getEntityValue($item, $groupBy);
                if (!array_key_exists($key, $data)) {
                    $data[$key] = [];
                }
                $data[$key][] = $item;
            }
        }
        return $data;
    }

    public static function indexBy($arr, $indexBy)
    {
        $data = [];
        if (is_array($arr)) {
            foreach ($arr as $item) {
                $data[self::getEntityValue($item, $indexBy)] = $item;
            }
        }
        return $data;
    }

}
