<?php

namespace Polkurier\Util;

class ParameterBag
{

    /**
     * @var array<string, mixed>
     */
    private $data;

    /**
     * @param array<string, mixed> $data
     */
    public function __construct($data)
    {
        $this->data = $data;
    }

    /**
     * @return array<string, mixed>
     */
    public function all()
    {
        return $this->data;
    }

    /**
     * @param string $key
     * @param mixed $default
     * @return mixed|null
     */
    public function get($key, $default = null)
    {
        return Arr::get($this->data, $key, $default);
    }

    /**
     * @param string $key
     * @param string $default
     * @return string
     */
    public function getString($key, $default = '')
    {
        return (string)$this->get($key, $default);
    }

    /**
     * @param string $key
     * @param int $default
     * @return int
     */
    public function getInt($key, $default = 0)
    {
        return (int)$this->get($key, $default);
    }

    /**
     * @param string $key
     * @param float $default
     * @return float
     */
    public function getFloat($key, $default = 0.0)
    {
        return (float)$this->get($key, $default);
    }

    /**
     * @param string $key
     * @param array $default
     * @return array
     */
    public function getArray($key, $default = [])
    {
        return (array)$this->get($key, $default);
    }

    /**
     * @param string $key
     * @param bool $default
     * @return bool
     */
    public function getBoolean($key, $default = false)
    {
        return (bool)filter_var($this->get($key, $default), FILTER_VALIDATE_BOOLEAN);
    }

}
